package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.TmstrainLoadingResultMapper;
import com.steerinfo.dil.mapper.TmstrainTotalResultMapper;
import com.steerinfo.dil.mapper.TmstrainTruckTotalResultMapper;
import com.steerinfo.dil.mapper.TmstrainWagonUnloadResultMapper;
import com.steerinfo.dil.model.TmstrainLoadingResult;
import com.steerinfo.dil.model.TmstrainTotalResult;
import com.steerinfo.dil.model.TmstrainTruckTotalResult;
import com.steerinfo.dil.model.TmstrainWagonUnloadResult;
import com.steerinfo.dil.service.ITmstrainWagonUnloadResultService;
import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * TmstrainWagonUnloadResult服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-08-19 09:22
 * 类描述
 * 修订历史：
 * 日期：2021-08-19
 * 作者：generator
 * 参考：
 * 描述：TmstrainWagonUnloadResult服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "tmstrainWagonUnloadResultService")
public class TmstrainWagonUnloadResultServiceImpl implements ITmstrainWagonUnloadResultService {

    @Autowired
    private TmstrainWagonUnloadResultMapper tmstrainWagonUnloadResultMapper;

    @Autowired
    private TmstrainLoadingResultServiceImpl tmstrainLoadingResultService;

    @Autowired
    private TmstrainTotalResultMapper tmstrainTotalResultMapper;

    @Autowired
    private TmstrainTruckTotalResultMapper tmstrainTruckTotalResultMapper;

    @Autowired
    private TmstrainLoadingResultMapper tmstrainLoadingResultMapper;
    /**
     * 查看所有卸车实绩
     * 1采购进口矿（万州港-达州站/万州港-老区轨道衡） 2采购进口矿（海港-老区轨道衡） 3采购国产矿  4内转
     * @param map
     * @return
     */
    @Override
    public List<Map<String, Object>> getTmstrainWagonUnLoad(Map<String, Object> map) {
        BigDecimal resultType = DataChange.dataToBigDecimal(map.get("resultType"));
        switch (resultType.intValue()){
            case 1:
            case 2:
            case 3:
                return tmstrainWagonUnloadResultMapper.getTmsWagonUnLoadInfo(map); //apiId: 60
            case 4:
                return tmstrainWagonUnloadResultMapper.selectWagonUnLoadResultForNZ(map);//apiId:256
            case 5: //内转国产矿 万州-达州
                return tmstrainWagonUnloadResultMapper.getTrainUnloadDaZhouToDaGang(map); //apiId:367
            case 6://内转国产矿 万州-老区轨道横
                return tmstrainWagonUnloadResultMapper.getTrainUnloadLaoQuToDaGgang(map); //apiId:367
        }
        return null;
    }

    /**
     * 删除卸车实绩
     * @param unloadingId
     * @return
     */
    @Override
    public int deleteTmstrainWagonUnLoadResultByUnLoadingId(BigDecimal unloadingId) {
        TmstrainWagonUnloadResult tmstrainWagonUnloadResult = new TmstrainWagonUnloadResult();
        tmstrainWagonUnloadResult.setId(unloadingId);
        tmstrainWagonUnloadResult.setDeleted(new BigDecimal(1));
        return tmstrainWagonUnloadResultMapper.updateByPrimaryKeySelective(tmstrainWagonUnloadResult);
    }

    /**
     * 新增车皮卸车
     * 1采购进口矿（万州港-达州站/万州港-老区轨道衡） 2采购进口矿（海港-老区轨道衡） 3采购国产矿  4内转
     * @param tmstrainWagonUnloadResult
     * @return
     */
    @Transactional(rollbackFor = Exception.class)
    public int insertTmstrainWagonUnLoadResult(TmstrainWagonUnloadResult tmstrainWagonUnloadResult) throws Exception {
        int i = 0;
        BigDecimal resultType = tmstrainWagonUnloadResult.getResultType();
        switch (resultType.intValue()){
            case 1:
            case 2:
            case 3:
                i = addTmstrainWagonLoadResult(tmstrainWagonUnloadResult);
                break;
        }
        return i;
    }

    /**
     * 采购进口矿新增卸车实绩
     * @param tmstrainWagonUnloadResult
     * @return
     */
    public int addTmstrainWagonLoadResult(TmstrainWagonUnloadResult tmstrainWagonUnloadResult) throws Exception {
        //常规字段插入
        //tmstrainWagonUnloadResult.setInsertUsername("admin");
        tmstrainWagonUnloadResult.setInsertTime(new Date());
        tmstrainWagonUnloadResult.setDeleted(new BigDecimal(0));
        List<Map<String, Object>> wagonNoMapList = tmstrainWagonUnloadResult.getWagonNoList();
        int count = 0;
        for (Map<String, Object> map : wagonNoMapList) {
            String resultWagonNo = (String) map.get("resultWagonNo");
            //通过装车车皮号得到并插入采购订单id
            tmstrainWagonUnloadResult.setPurchaseOrderRailPlanId(DataChange.dataToBigDecimal(map.get("purchaseOrderId")));
            //生成主键id
            tmstrainWagonUnloadResult.setUnloadingId(tmstrainWagonUnloadResultMapper.selectMaxId());
            //查询装车实绩中的卸货点传入数据（改成前端传入）
            //tmstrainWagonUnloadResult.setUnloadingPointId(DataChange.dataToBigDecimal(map.get("unloadingPointId")));
            tmstrainWagonUnloadResult.setResultWagonNo(resultWagonNo);
            count += tmstrainWagonUnloadResultMapper.insertSelective(tmstrainWagonUnloadResult);
            count += updateLoadingResult(map); //修改装车实绩为已卸货
        }
        return count;
    }


    /**
     * 修改卸车实绩
     * @param tmstrainWagonUnloadResult
     * @return
     */
    @Override
    public int updateTmstrainWagonUnLoadResult(TmstrainWagonUnloadResult tmstrainWagonUnloadResult) {
        tmstrainWagonUnloadResult.setUpdateTime(new Date());
        return tmstrainWagonUnloadResultMapper.updateByPrimaryKeySelective(tmstrainWagonUnloadResult);
    }

    /**
     * 修改装车实绩状态为已卸车
     * @param map
     * @return
     */
    public int updateLoadingResult(Map<String, Object> map) throws Exception {
        //添加一条卸货实绩 修改装车状态为已卸车 2
        TmstrainLoadingResult tmstrainLoadingResult = new TmstrainLoadingResult();
        tmstrainLoadingResult.setResultId(DataChange.dataToBigDecimal(map.get("resultId")));
        tmstrainLoadingResult.setDeleted(new BigDecimal(2));
        return tmstrainLoadingResultMapper.updateByPrimaryKeySelective(tmstrainLoadingResult);
    }

    /**
     * 查看火运实绩
     * @param map
     * @return
     */
    @Override
    public List<Map<String, Object>> getTmstrainResult(Map<String, Object> map) {
        return tmstrainWagonUnloadResultMapper.getTmstrainResult(map);
    }

    @Override
    public List<Map<String, Object>> getUnloadingPointName() {
        return tmstrainWagonUnloadResultMapper.getUnloadingPointName();
    }

    @Override
    public List<Map<String, Object>> getUnloadingRouteName() {
        return tmstrainWagonUnloadResultMapper.getUnloadingRouteName();
    }

    /**
     * 通过主键查询信息
     * @param unloadingId
     * @return
     */
    @Override
    public List<Map<String, Object>> getTmstrainWagonUnLoadResultByUnLoadingId(BigDecimal unloadingId) {
        return tmstrainWagonUnloadResultMapper.selectByUnLoadingId(unloadingId);
    }


    /**
     * 内转物流新增卸车实绩
     *      "orderId": 2,
     *     "materialId": 197,
     *     "arrivalDate": 1637910978000,
     *     "bigTicketWeight":111,
     *     "railHorizontalWeight":110
     * @param map
     * @return
     */
    @Transactional
    public int addTmsTrainUnloadResultForNZ(Map<String, Object> map) {
        BigDecimal orderId = DataChange.dataToBigDecimal(map.get("orderId"));
        BigDecimal materialId = DataChange.dataToBigDecimal(map.get("materialId"));
        //通过传入的运输订单ID查询这个运输订单关联的火运总实绩和汽运总实绩
        List<Map<String, Object>> totalIdList = tmstrainWagonUnloadResultMapper.getTotalIdByOrderId(orderId);
        Map<String, Object> mesMap = totalIdList.get(0);
        BigDecimal trainTotalId = DataChange.dataToBigDecimal(mesMap.get("trainTotalId"));
        //通过汽运总实绩ID、火运总实绩ID 查找中间表主键
        Integer truckTrainId = tmstrainTruckTotalResultMapper.getIdByMateAndTruckAndTrainTotalId(mesMap);
        //如果没有查出中间表数据 说明该订单已经卸过车
        if(truckTrainId == null){
            return 1;
        }
        //通过火运总实绩ID查询装车实绩ID
        Integer loadingId = tmstrainWagonUnloadResultMapper.getLoadingIdByTrainTotalId(trainTotalId);
        //拿到装车实绩ID后查询车皮号与发运计划号
        Map<String, Object> noAndIdMap = tmstrainWagonUnloadResultMapper.getWagonNoAndRailPlanByLoadingId(loadingId);
        String resultWagonNo = (String) noAndIdMap.get("resultWagonNo");
        BigDecimal railPlanId = DataChange.dataToBigDecimal(noAndIdMap.get("railPlanId"));
        //通过车皮号与发运计划号匹配卸车作业中是否含有记录
        Integer unloadId = tmstrainWagonUnloadResultMapper.getUnloadIdByWagonNoAndRailPlanId(resultWagonNo, railPlanId);
        //如果没有卸车实绩则新增卸车实绩
        int count = 0;
        if(unloadId == null){
            TmstrainWagonUnloadResult tmstrainWagonUnloadResult = new TmstrainWagonUnloadResult();
            BigDecimal maxId = tmstrainWagonUnloadResultMapper.selectMaxId();
            tmstrainWagonUnloadResult.setId(maxId);
            tmstrainWagonUnloadResult.setResultWagonNo(resultWagonNo);//添加车皮号
            tmstrainWagonUnloadResult.setPurchaseOrderRailPlanId(railPlanId);//添加发运计划ID
            tmstrainWagonUnloadResult.setResultUnloadTime(new Date());//卸车日期
            tmstrainWagonUnloadResult.setResultArrivalDate(new Date((long) map.get("arrivalDate")));//到达日期
            tmstrainWagonUnloadResult.setResultBigTicketWeight(DataChange.dataToBigDecimal(map.get("bigTicketWeight")));//大票重量
            tmstrainWagonUnloadResult.setResultRailHorizontalWeight(DataChange.dataToBigDecimal(map.get("railHorizontalWeight")));//轨道衡重量
            tmstrainWagonUnloadResult.setDeleted(new BigDecimal(0));
            tmstrainWagonUnloadResult.setResultType(new BigDecimal(4));
            tmstrainWagonUnloadResult.setInsertTime(new Date());
            tmstrainWagonUnloadResult.setInsertUsername("admin");
            count += tmstrainWagonUnloadResultMapper.insertSelective(tmstrainWagonUnloadResult);
            //往火运总实绩中添加卸车实绩
            TmstrainTotalResult tmstrainTotalResult = new TmstrainTotalResult();
            tmstrainTotalResult.setTotalResultId(trainTotalId);
            tmstrainTotalResult.setUnloadingId(maxId);
            tmstrainTotalResult.setUpdateTime(new Date());
            count += tmstrainTotalResultMapper.updateByPrimaryKeySelective(tmstrainTotalResult);
        }
        //修改火运物资中间表为已卸车
        TmstrainTruckTotalResult tmstrainTruckTotalResult = new TmstrainTruckTotalResult();
        tmstrainTruckTotalResult.setId(new BigDecimal(truckTrainId));
        tmstrainTruckTotalResult.setLoadStatus(new BigDecimal(1));//已卸车
        count += tmstrainTruckTotalResultMapper.updateByPrimaryKeySelective(tmstrainTruckTotalResult);
        return count;
    }

    @Override
    public List<Map<String, Object>> selectWagonUnLoadResult(Map<String, Object> map) {
        return tmstrainWagonUnloadResultMapper.selectWagonUnLoadResultForNZ(map);
    }


    /**
     * 内转物流展示火车卸货实绩
     * @param map
     * @return
     */
    @Override
    public List<Map<String, Object>> getTrainResult(Map<String, Object> map) {
        return tmstrainWagonUnloadResultMapper.getTrainResult(map);
    }

}
